@@ -211,7 +211,7 @@ class TestQuickStartTemplates(BaseCliTestCase):
                             "test/fixtures/templates/good/transform_serverless_globals.yaml"
                         )
                     ),
-                    "Id": "f69e6049-a69c-5754-4744-74aa1c4ae90d",
+                    "Id": "0d9d3690-14a9-8a30-2bf4-d6515e1fe983",
                     "Level": "Error",
                     "Location": {
                         "End": {"ColumnNumber": 13, "LineNumber": 10},
@@ -220,8 +220,8 @@ class TestQuickStartTemplates(BaseCliTestCase):
                     },
                     "Message": (
                         "Runtime 'nodejs6.10' was deprecated on '2019-08-12'. Creation"
-                        " was disabled on '2019-08-12' and update on '2019-08-12'."
-                        " Please consider updating to 'nodejs22.x'"
+                        " was disabled on '2019-07-12' and update on '2019-08-12'."
+                        " Please consider updating to 'nodejs24.x'"
                     ),
                     "ParentId": None,
                     "Rule": {
